@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 """The jsonpickle.tags module provides the custom tags
 used for pickling and unpickling Python objects.
 
@@ -9,12 +11,14 @@ that need to be specially handled.
 from jsonpickle.compat import set
 
 
+BYTES = 'py/bytes'
 FUNCTION = 'py/function'
 ID = 'py/id'
 INITARGS = 'py/initargs'
 ITERATOR = 'py/iterator'
 JSON_KEY = 'json://'
 NEWARGS = 'py/newargs'
+NEWARGSEX = 'py/newargsex'
 NEWOBJ = 'py/newobj'
 OBJECT = 'py/object'
 REDUCE = 'py/reduce'
@@ -28,11 +32,13 @@ TYPE = 'py/type'
 
 # All reserved tag names
 RESERVED = set([
+    BYTES,
     FUNCTION,
     ID,
     INITARGS,
     ITERATOR,
     NEWARGS,
+    NEWARGSEX,
     NEWOBJ,
     OBJECT,
     REDUCE,
