@@ -21,6 +21,8 @@ from jsonpickle.compat import unicode
 from jsonpickle.compat import unichr
 from jsonpickle.compat import PY32, PY3
 
+from helper import SkippableTest
+
 
 class Thing(object):
 
@@ -32,6 +34,12 @@ class Thing(object):
         return 'Thing("%s")' % self.name
 
 
+class Capture(object):
+    def __init__(self, *args, **kwargs):
+        self.args = args
+        self.kwargs = kwargs
+
+
 class ThingWithProps(object):
 
     def __init__(self, name='', dogs='reliable', monkies='tricksy'):
@@ -90,8 +98,10 @@ class PicklingTestCase(unittest.TestCase):
         self.assertEqual('a string', self.unpickler.restore('a string'))
 
     def test_unicode(self):
-        self.assertEqual(unicode('a string'), self.pickler.flatten('a string'))
-        self.assertEqual(unicode('a string'), self.unpickler.restore('a string'))
+        self.assertEqual(unicode('a string'),
+                         self.pickler.flatten('a string'))
+        self.assertEqual(unicode('a string'),
+                         self.unpickler.restore('a string'))
 
     def test_int(self):
         self.assertEqual(3, self.pickler.flatten(3))
@@ -141,7 +151,8 @@ class PicklingTestCase(unittest.TestCase):
         self.assertEqual(setA, self.unpickler.restore(setA_pickle))
 
     def test_dict(self):
-        dictA = {'key1': 1.0, 'key2': 20, 'key3': 'thirty', tags.JSON_KEY + '6': 6}
+        dictA = {'key1': 1.0, 'key2': 20, 'key3': 'thirty',
+                 tags.JSON_KEY + '6': 6}
         self.assertEqual(dictA, self.pickler.flatten(dictA))
         self.assertEqual(dictA, self.unpickler.restore(dictA))
         dictB = {}
@@ -371,7 +382,7 @@ class PicklingTestCase(unittest.TestCase):
         self.assertTrue(expect is actual)
 
 
-class JSONPickleTestCase(unittest.TestCase):
+class JSONPickleTestCase(SkippableTest):
 
     def setUp(self):
         self.obj = Thing('A name')
@@ -485,7 +496,7 @@ class JSONPickleTestCase(unittest.TestCase):
         self.assertEqual(unpickled[tags.JSON_KEY + '6'], [1, 2])
 
     def test_string_key_not_requiring_escape_dict_keys_with_keys_enabled(self):
-        """ test that string keys that does not require escaping are not escaped """
+        """test that string keys that do not require escaping are not escaped"""
         str_dict = {'name': [1, 2]}
         pickled = jsonpickle.encode(str_dict, keys=True)
         unpickled = jsonpickle.decode(pickled)
@@ -556,8 +567,7 @@ class JSONPickleTestCase(unittest.TestCase):
 
         """
         if PY32:
-            self.skipTest('no simplejson for python 3.2')
-            return
+            return self.skip('no simplejson for python 3.2')
         jsonpickle.load_backend('simplejson', 'dumps', 'loads', ValueError)
         self.assertTrue(True)
 
@@ -605,7 +615,8 @@ class JSONPickleTestCase(unittest.TestCase):
         """Test that we ignore bad decoders"""
 
         load_backend = jsonpickle.load_backend
-        self.assertFalse(load_backend('os.path', 'join', 'bad!', AttributeError))
+        self.assertFalse(load_backend('os.path', 'join', 'bad!',
+                                      AttributeError))
         self.failIf(self._backend_is_partially_loaded('os.path'))
 
     def test_load_backend_handles_bad_loads_exc(self):
@@ -1000,7 +1011,7 @@ class PicklingProtocol4TestCase(unittest.TestCase):
         self.assertFalse(decoded.__class__ is PicklableNamedTupleEx)
 
 
-class PicklingProtocol2TestCase(unittest.TestCase):
+class PicklingProtocol2TestCase(SkippableTest):
 
     def test_classic_init_has_args(self):
         """
@@ -1009,7 +1020,7 @@ class PicklingProtocol2TestCase(unittest.TestCase):
         Because classic only exists under 2, skipped if PY3
         """
         if PY3:
-            self.skipTest('No classic classes in PY3')
+            return self.skip('No classic classes in PY3')
         instance = PickleProtocol2Classic(3)
         encoded = jsonpickle.encode(instance)
         decoded = jsonpickle.decode(encoded)
@@ -1022,7 +1033,7 @@ class PicklingProtocol2TestCase(unittest.TestCase):
         Because classic only exists under 2, skipped if PY3
         """
         if PY3:
-            self.skipTest('No classic classes in PY3')
+            return self.skip('No classic classes in PY3')
         instance = PickleProtocol2ClassicInitargs(3)
         encoded = jsonpickle.encode(instance)
         decoded = jsonpickle.decode(encoded)
@@ -1096,9 +1107,8 @@ class PicklingProtocol2TestCase(unittest.TestCase):
         self.assertEqual(decoded.foo, 1)
 
     def test_reduce_basic(self):
-        """
-        Test reduce with only callable and args
-        """
+        """Test reduce with only callable and args"""
+
         instance = PickleProtocol2ReduceTuple(5)
         encoded = jsonpickle.encode(instance)
         decoded = jsonpickle.decode(encoded)
@@ -1106,8 +1116,10 @@ class PicklingProtocol2TestCase(unittest.TestCase):
         self.assertEqual(decoded.optional, 1)
 
     def test_reduce_basic_func(self):
-        """
-        Test reduce with only callable and args, where callable is a module-level function
+        """Test reduce with only callable and args
+
+        callable is a module-level function
+
         """
         instance = PickleProtocol2ReduceTupleFunc(5)
         encoded = jsonpickle.encode(instance)
@@ -1116,8 +1128,10 @@ class PicklingProtocol2TestCase(unittest.TestCase):
         self.assertEqual(decoded.optional, 1)
 
     def test_reduce_newobj(self):
-        """
-        Test reduce with callable called __newobj__ - ensure special-case behaviour
+        """Test reduce with callable called __newobj__
+
+        ensures special-case behaviour
+
         """
         instance = PickleProtocol2ReduceNewobj(5)
         encoded = jsonpickle.encode(instance)
@@ -1247,8 +1261,8 @@ class PicklingProtocol2TestCase(unittest.TestCase):
         self.assertTrue(decoded.args[0] is decoded.args[1])
 
     def test_handles_cyclical_objects(self):
-        child = PickleProtocol2Thing(None)
-        instance = PickleProtocol2Thing(child, child)
+        child = Capture(None)
+        instance = Capture(child, child)
         child.args = (instance,)  # create a cycle
         # TODO we do not properly restore references inside of lists.
         # Change the above tuple into a list to show the breakage.
@@ -1257,27 +1271,27 @@ class PicklingProtocol2TestCase(unittest.TestCase):
         decoded = jsonpickle.decode(encoded)
 
         # Ensure the right objects were constructed
-        self.assertEqual(PickleProtocol2Thing, decoded.__class__)
-        self.assertEqual(PickleProtocol2Thing, decoded.args[0].__class__)
-        self.assertEqual(PickleProtocol2Thing, decoded.args[1].__class__)
-        self.assertEqual(PickleProtocol2Thing, decoded.args[0].args[0].__class__)
-        self.assertEqual(PickleProtocol2Thing, decoded.args[1].args[0].__class__)
+        self.assertEqual(Capture, decoded.__class__)
+        self.assertEqual(Capture, decoded.args[0].__class__)
+        self.assertEqual(Capture, decoded.args[1].__class__)
+        self.assertEqual(Capture, decoded.args[0].args[0].__class__)
+        self.assertEqual(Capture, decoded.args[1].args[0].__class__)
 
         # It's turtles all the way down
-        self.assertEqual(PickleProtocol2Thing, decoded.args[0].args[0]
-                                                      .args[0].args[0]
-                                                      .args[0].args[0]
-                                                      .args[0].args[0]
-                                                      .args[0].args[0]
-                                                      .args[0].args[0]
-                                                      .args[0].args[0]
-                                                      .args[0].__class__)
+        self.assertEqual(Capture, decoded.args[0].args[0]
+                                         .args[0].args[0]
+                                         .args[0].args[0]
+                                         .args[0].args[0]
+                                         .args[0].args[0]
+                                         .args[0].args[0]
+                                         .args[0].args[0]
+                                         .args[0].__class__)
         # Ensure that references are properly constructed
         self.assertTrue(decoded.args[0] is decoded.args[1])
         self.assertTrue(decoded is decoded.args[0].args[0])
         self.assertTrue(decoded is decoded.args[1].args[0])
         self.assertTrue(decoded.args[0] is decoded.args[0].args[0].args[0])
-        self.assertTrue(decoded.args[0] is decoded.args[0].args[1].args[0])
+        self.assertTrue(decoded.args[0] is decoded.args[1].args[0].args[0])
 
     def test_handles_cyclical_objects_in_lists(self):
         child = PickleProtocol2ChildThing(None)
