@@ -5,11 +5,14 @@ import decimal
 import re
 import sys
 import unittest
+import datetime
 
 import jsonpickle
 from jsonpickle import handlers
 from jsonpickle import tags
-from jsonpickle.compat import queue, set, unicode, bytes, PY2
+from jsonpickle.compat import queue, set, unicode, bytes, PY2, PY_MINOR
+
+from helper import SkippableTest
 
 
 class Thing(object):
@@ -183,12 +186,33 @@ try:
     class StringEnumTest(enum.Enum):
         A = 'a'
         B = 'b'
+
+    class SubEnum(enum.Enum):
+        a = 1
+        b = 2
+
+    class EnumClass(object):
+
+        def __init__(self):
+            self.enum_a = SubEnum.a
+            self.enum_b = SubEnum.b
+
+
 except ImportError:
     IntEnumTest = None
     StringEnumTest = None
+    EnumClass = None
 
 
-class AdvancedObjectsTestCase(unittest.TestCase):
+class ThingWithTimedeltaAttribute(object):
+    def __init__(self, offset):
+        self.offset = datetime.timedelta(offset)
+
+    def __getinitargs__(self):
+        return self.offset,
+
+
+class AdvancedObjectsTestCase(SkippableTest):
 
     def setUp(self):
         self.pickler = jsonpickle.pickler.Pickler()
@@ -201,37 +225,40 @@ class AdvancedObjectsTestCase(unittest.TestCase):
     def test_defaultdict_roundtrip(self):
         """Make sure we can handle collections.defaultdict(list)"""
         # setup
-        defaultdict = collections.defaultdict(list)
-        defaultdict['a'] = 1
-        defaultdict['b'].append(2)
-        defaultdict['c'] = collections.defaultdict(dict)
+        defaultdict = collections.defaultdict
+        defdict = defaultdict(list)
+        defdict['a'] = 1
+        defdict['b'].append(2)
+        defdict['c'] = defaultdict(dict)
         # jsonpickle work your magic
-        encoded = jsonpickle.encode(defaultdict)
-        newdefaultdict = jsonpickle.decode(encoded)
+        encoded = jsonpickle.encode(defdict)
+        newdefdict = jsonpickle.decode(encoded)
         # jsonpickle never fails
-        self.assertEqual(newdefaultdict['a'], 1)
-        self.assertEqual(newdefaultdict['b'], [2])
-        self.assertEqual(type(newdefaultdict['c']), collections.defaultdict)
-        self.assertEqual(defaultdict.default_factory, list)
-        self.assertEqual(newdefaultdict.default_factory, list)
+        self.assertEqual(newdefdict['a'], 1)
+        self.assertEqual(newdefdict['b'], [2])
+        self.assertEqual(type(newdefdict['c']), defaultdict)
+        self.assertEqual(defdict.default_factory, list)
+        self.assertEqual(newdefdict.default_factory, list)
 
     def test_defaultdict_roundtrip_simple_lambda(self):
-        """Make sure we can handle collections.defaultdict(lambda: defaultdict(int))"""
+        """Make sure we can handle defaultdict(lambda: defaultdict(int))"""
         # setup a sparse collections.defaultdict with simple lambdas
-        defaultdict = collections.defaultdict(lambda: collections.defaultdict(int))
-        defaultdict[0] = 'zero'
-        defaultdict[1] = collections.defaultdict(lambda: collections.defaultdict(dict))
-        defaultdict[1][0] = 'zero'
+        defaultdict = collections.defaultdict
+        defdict = defaultdict(lambda: defaultdict(int))
+        defdict[0] = 'zero'
+        defdict[1] = defaultdict(lambda: defaultdict(dict))
+        defdict[1][0] = 'zero'
         # roundtrip
-        encoded = jsonpickle.encode(defaultdict, keys=True)
-        newdefaultdict = jsonpickle.decode(encoded, keys=True)
-        self.assertEqual(newdefaultdict[0], 'zero')
-        self.assertEqual(type(newdefaultdict[1]), collections.defaultdict)
-        self.assertEqual(newdefaultdict[1][0], 'zero')
-        self.assertEqual(newdefaultdict[1][1], {})  # inner defaultdict
-        self.assertEqual(newdefaultdict[2][0], 0)  # outer defaultdict
-        self.assertEqual(type(newdefaultdict[3]), collections.defaultdict)
-        self.assertEqual(newdefaultdict[3].default_factory, int)  # outer-most defaultdict
+        encoded = jsonpickle.encode(defdict, keys=True)
+        newdefdict = jsonpickle.decode(encoded, keys=True)
+        self.assertEqual(newdefdict[0], 'zero')
+        self.assertEqual(type(newdefdict[1]), defaultdict)
+        self.assertEqual(newdefdict[1][0], 'zero')
+        self.assertEqual(newdefdict[1][1], {})  # inner defaultdict
+        self.assertEqual(newdefdict[2][0], 0)  # outer defaultdict
+        self.assertEqual(type(newdefdict[3]), defaultdict)
+        # outer-most defaultdict
+        self.assertEqual(newdefdict[3].default_factory, int)
 
     def test_defaultdict_subclass_with_self_as_default_factory(self):
         cls = ThingWithSelfAsDefaultFactory
@@ -278,7 +305,11 @@ class AdvancedObjectsTestCase(unittest.TestCase):
 
     def test_deque_roundtrip(self):
         """Make sure we can handle collections.deque"""
-        old_deque = collections.deque([0, 1, 2])
+        py26 = PY2 and PY_MINOR < 7
+        if py26:
+            old_deque = collections.deque([0, 1, 2])
+        else:
+            old_deque = collections.deque([0, 1, 2], maxlen=5)
         encoded = jsonpickle.encode(old_deque)
         new_deque = jsonpickle.decode(encoded)
         self.assertNotEqual(encoded, 'nil')
@@ -288,6 +319,9 @@ class AdvancedObjectsTestCase(unittest.TestCase):
         self.assertEqual(new_deque[1], 1)
         self.assertEqual(old_deque[2], 2)
         self.assertEqual(new_deque[2], 2)
+        if not py26:
+            self.assertEqual(old_deque.maxlen, 5)
+            self.assertEqual(new_deque.maxlen, 5)
 
     def test_namedtuple_roundtrip(self):
         old_nt = NamedTuple(0, 1, 2)
@@ -542,7 +576,8 @@ class AdvancedObjectsTestCase(unittest.TestCase):
         obj['key1'] = 1
 
         flattened = self.pickler.flatten(obj)
-        self.assertEqual({'key1': 1, tags.OBJECT: 'object_test.DictSubclass'}, flattened)
+        self.assertEqual({'key1': 1, tags.OBJECT: 'object_test.DictSubclass'},
+                         flattened)
         self.assertEqual(flattened[tags.OBJECT], 'object_test.DictSubclass')
 
         inflated = self.unpickler.restore(flattened)
@@ -676,20 +711,31 @@ class AdvancedObjectsTestCase(unittest.TestCase):
 
     def test_enum34(self):
         if IntEnumTest is None or StringEnumTest is None:
-            return self.skipTest('enum module is not importable')
-
-        roundtrip = lambda obj: self.unpickler.restore(self.pickler.flatten(obj))
+            return self.skip('enum34 module is not installed')
 
+        restore = self.unpickler.restore
+        flatten = self.pickler.flatten
+        roundtrip = lambda obj: restore(flatten(obj))
         self.assertTrue(roundtrip(IntEnumTest.X) is IntEnumTest.X)
         self.assertTrue(roundtrip(IntEnumTest) is IntEnumTest)
 
         self.assertTrue(roundtrip(StringEnumTest.A) is StringEnumTest.A)
         self.assertTrue(roundtrip(StringEnumTest) is StringEnumTest)
 
+    def test_enum34_nested(self):
+        if EnumClass is None:
+            return self.skip('enum34 module is not installed')
+        ec = EnumClass()
+        encoded = jsonpickle.encode(ec)
+        decoded = jsonpickle.decode(encoded)
+
+        self.assertEqual(ec.enum_a, decoded.enum_a)
+        self.assertEqual(ec.enum_b, decoded.enum_b)
+
     def test_bytes_unicode(self):
         b1 = b'foo'
         b2 = b'foo\xff'
-        u1 = u'foo'
+        u1 = unicode('foo')
 
         # unicode strings get encoded/decoded as is
         encoded = self.pickler.flatten(u1)
@@ -724,6 +770,12 @@ class AdvancedObjectsTestCase(unittest.TestCase):
         self.assertTrue(decoded == b2)
         self.assertTrue(type(decoded) is bytes)
 
+    def test_nested_objects(self):
+        obj = ThingWithTimedeltaAttribute(99)
+        flattened = self.pickler.flatten(obj)
+        restored = self.unpickler.restore(flattened)
+        self.assertEqual(restored.offset, datetime.timedelta(99))
+
 
 # Test classes for ExternalHandlerTestCase
 class Mixin(object):
