@@ -21,8 +21,10 @@ import document_test
 import handler_test
 import jsonpickle_test
 import object_test
-import thirdparty_test
 import util_test
+import feedparser_test
+import bson_test
+import numpy_test
 
 
 def suite():
@@ -34,7 +36,9 @@ def suite():
     suite.addTest(datetime_test.suite())
     suite.addTest(document_test.suite())
     suite.addTest(object_test.suite())
-    suite.addTest(thirdparty_test.suite())
+    suite.addTest(feedparser_test.suite())
+    suite.addTest(numpy_test.suite())
+    suite.addTest(bson_test.suite())
     return suite
 
 
